| compileModel | R Documentation |
This function translates MCSim model specification text to C and then compiles the resulting C file to create a dynamic link library (DLL) file (on Windows) or a shared object (SO) file (on Unix).
compileModel(
model_file,
c_file,
dll_name,
dll_file,
source_file = model_file,
hash_file = NULL,
verbose_output = FALSE
)
model_file |
Name of an MCSim model specification file. |
c_file |
Name of a C source code file to be created by compiling the MCSim model specification file. |
dll_name |
Name of a DLL or SO file without the extension (".dll" or ".so"). |
dll_file |
Name of the same DLL or SO file with the appropriate extension (".dll" or ".so"). |
source_file |
Name of the original source file to use for hash calculation. Defaults to |
hash_file |
Name of a file containing a hash key for determining if |
verbose_output |
Boolean specifying whether to write translator messages to standard output. If value is TRUE, messages will be written to standard output; if value is FALSE, messages will be written to files in a temporary directory. |
No return value. Creates files and saves them in locations specified by function arguments.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.