| createModel | R Documentation |
This function creates a Model object using an MCSim model specification
file or an MCSim model specification string.
createModel(
mName = character(0),
mString = character(0),
writeTemp = TRUE,
verboseOutput = FALSE
)
mName |
Name of an MCSim model specification file, excluding the file name extension |
mString |
A character string containing MCSim model specification text. |
writeTemp |
Boolean specifying whether to write model files to a temporary directory. If value is TRUE (the default), model files will be Written to a temporary directory; if value is FALSE, model files will be Written to the same directory that contains the model specification file. |
verboseOutput |
Boolean specifying whether to write translator messages to standard output. If value is TRUE, messages will be written to standard output; if value is FALSE, messages will be written to files in a temporary directory. |
Model object.
## Not run:
# Simple model
mod <- createModel("path/to/model")
# Load/compile the model
mod$loadModel()
# Update parameters (P1 and P2)
mod$updateParms(c(P1 = 3, P2 = 1))
# Define times for ODE simulation
times <- seq(from = 0, to = 24, by = 0.1)
# Run the simulation
out <- mod$runModel(times)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.